import { RuntimeError } from '@ibiz-template/core';
import { IPluginFactory } from '@ibiz-template/runtime';
import { IPSAppPFPluginRef, IPSSysPFPlugin } from '@ibiz/dynamic-model-api';
import Vue from 'vue';

/**
 * 插件工具类
 *
 * @author chitanda
 * @date 2022-10-21 16:10:29
 * @export
 * @class PluginFactory
 */
export class PluginFactory implements IPluginFactory {
  async loadPlugin(plugin: IPSSysPFPlugin): Promise<void> {
    if (plugin.runtimeObject === true) {
      const pluginRef = plugin as unknown as IPSAppPFPluginRef;
      if (pluginRef) {
        const code = pluginRef.templCode;
        if (code) {
          const module = await System.import(code);
          if (module) {
            if (module.default) {
              Vue.use(module.default);
            } else {
              throw new RuntimeError(
                `远程插件加载失败, 远程插件未找到[default]默认导出`,
              );
            }
          } else {
            throw new RuntimeError(`远程插件加载失败, 未找到文件`);
          }
        }
      }
    }
  }
}
